@@ -1,14 +1,15 @@
 #!/bin/sh
 echo 'name: cairo
-version: 0.12.0
-id: cairo-0.12.0-0c72e956066deed849e92270e97178b5
+version: 0.12.3.1
+id: cairo-0.12.3.1-6f21c8a5ac9f94b82a99988c05148ef2
 
 license: BSD3
 copyright: (c) 2001-2010 The Gtk2Hs Team, (c) Paolo Martini 2005, (c) Abraham Egnor 2003, 2004, (c) Aetion Technologies LLC 2004
-maintainer: gtk2hs-users@sourceforge.net
+maintainer: gtk2hs-users@lists.sourceforge.net
 stability: stable
-homepage: http://www.haskell.org/gtk2hs/
+homepage: http://projects.haskell.org/gtk2hs/
 package-url:
+synopsis: Binding to the Cairo library.
 description: Cairo is a library to render high quality vector graphics. There
              exist various backends that allows rendering to Gtk windows, PDF,
              PS, PNG and SVG documents, amongst others.
@@ -32,29 +33,27 @@ hidden-modules: Graphics.Rendering.Cairo.Internal.Drawing.Cairo
                 Graphics.Rendering.Cairo.Internal.Surfaces.PDF
                 Graphics.Rendering.Cairo.Internal.Surfaces.PS
                 Graphics.Rendering.Cairo.Internal.Surfaces.SVG
-import-dirs: /usr/local/lib/ghc/cairo-0.12.0
-library-dirs: /usr/local/lib/ghc/cairo-0.12.0 /usr/local/lib
-              /usr/X11R6/lib
-hs-libraries: HScairo-0.12.0
-extra-libraries: cairo gobject-2.0 gthread-2.0 glib-2.0 intl iconv
-                 pixman-1 pthread-stubs fontconfig expat freetype GL png z m xcb-shm
-                 xcb-render xcb Xrender X11
+trusted: False
+import-dirs: /usr/local/lib/ghc/cairo-0.12.3.1
+library-dirs: /usr/local/lib/ghc/cairo-0.12.3.1 /usr/local/lib
+hs-libraries: HScairo-0.12.3.1
+extra-libraries: z cairo
 extra-ghci-libraries:
 include-dirs: /usr/local/include/cairo /usr/local/include/glib-2.0
-              /usr/local/lib/glib-2.0/include /usr/X11R6/include/pixman-1
-              /usr/X11R6/include /usr/X11R6/include/freetype2
-              /usr/include/dev/pci/drm /usr/local/include/libpng
+              /usr/local/lib/glib-2.0/include /usr/local/include
+              /usr/X11R6/include/pixman-1 /usr/X11R6/include
+              /usr/X11R6/include/freetype2 /usr/include
+              /usr/local/include/libpng16
 includes:
-depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
-         base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
-         bytestring-0.9.1.10-2da7b519f76934c0e733bf92c23382ec
-         haskell98-1.1.0.1-94f7a5cdbf7a4c3cb91e841ae24bf4c0
-         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
+depends: array-0.4.0.1-6380782b62ead58fec616aa07dc0e15c
+         base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
+         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
+         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
 hugs-options:
 cc-options:
-ld-options: -pthread
+ld-options: "-Wl,-rpath-link,/usr/X11R6/lib"
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-cairo-0.12.0/html/cairo.haddock
-haddock-html: /usr/local/share/doc/hs-cairo-0.12.0/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-cairo-0.12.3.1/html/cairo.haddock
+haddock-html: /usr/local/share/doc/hs-cairo-0.12.3.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
